@@ -1,3 +1,22 @@
+/*
+  This file is part of SNPknock.
+
+    Copyright (C) 2017-2018 Matteo Sesia
+
+    SNPknock is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    SNPknock is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with SNPknock.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
 #ifndef HAPLOTYPES_H
 #define HAPLOTYPES_H
 
@@ -8,6 +27,7 @@ Knockoffs for phased haplotypes
 #include <vector>
 #include <random>
 #include "utils.h"
+#include <iostream>
 
 typedef std::vector< std::vector<double> > matrix;
 typedef std::vector< std::vector<int> > imatrix;
@@ -31,7 +51,6 @@ namespace knockoffs {
     std::vector<int> H, Hk, Xk;
     // Partition function for Markov chain knockoffs
     std::vector<double> Z, Z_old;
-    std::vector<double> Z_sums;
     // Random number generation
     std::random_device rd;
     std::mt19937 gen;
